=======
History
=======

0.1.9 (2021-20-09)
------------------

* Added version option to CLI
* Changed 'generate' command to point to EVOLVED-5G/template at Github
* Added template option to point to your user's template. Used in tests by default pointing at skolome/netapp-ckcutter-template


0.1.4 (2021-17-09)
------------------

* Added documentation to "generate" command
* Added documentation to readthedocs 

0.1.1 (2021-07-08)
------------------

* Generate command more fleshed out
* Added more detailed pytests 


0.1.0 (2021-06-30)
------------------

* First prototype implementation
